[ARVADOS-DEV] created: b4ec5ebe8119d493712204ee2de7d513fab45ee6

git at public.curoverse.com git at public.curoverse.com
Wed Apr 8 10:16:06 EDT 2015


        at  b4ec5ebe8119d493712204ee2de7d513fab45ee6 (commit)


commit b4ec5ebe8119d493712204ee2de7d513fab45ee6
Author: Tom Clegg <tom at curoverse.com>
Date:   Wed Apr 8 10:17:16 2015 -0400

    5416: Run keepproxy, arv-git-httpd, and SSL proxy services during Workbench test suites.

diff --git a/jenkins/run-tests.sh b/jenkins/run-tests.sh
index 545c847..036a531 100755
--- a/jenkins/run-tests.sh
+++ b/jenkins/run-tests.sh
@@ -129,7 +129,7 @@ report_outcomes() {
 exit_cleanly() {
     trap - INT
     rotate_logfile "$WORKSPACE/apps/workbench/log/" "test.log"
-    stop_api
+    stop_services
     rotate_logfile "$WORKSPACE/services/api/log/" "test.log"
     report_outcomes
     clear_temp
@@ -242,7 +242,23 @@ start_api() {
         && (env | egrep ^ARVADOS)
 }
 
-stop_api() {
+start_nginx_proxy_services() {
+    echo 'Starting keepproxy, arv-git-httpd, and nginx ssl proxy...'
+    cd "$WORKSPACE" \
+        && python sdk/python/tests/run_test_server.py start_keep_proxy \
+        && python sdk/python/tests/run_test_server.py start_arv_git_httpd \
+        && python sdk/python/tests/run_test_server.py start_nginx \
+        && export ARVADOS_TEST_PROXY_SERVICES=1
+}
+
+stop_services() {
+    if [[ -n "$ARVADOS_TEST_PROXY_SERVICES" ]]; then
+        unset ARVADOS_TEST_PROXY_SERVICES
+        cd "$WORKSPACE" \
+            && python sdk/python/tests/run_test_server.py stop_nginx \
+            && python sdk/python/tests/run_test_server.py stop_arv_git_httpd \
+            && python sdk/python/tests/run_test_server.py stop_keep_proxy
+    fi
     if [[ -n "$ARVADOS_TEST_API_HOST" ]]; then
         unset ARVADOS_TEST_API_HOST
         cd "$WORKSPACE" \
@@ -594,7 +610,7 @@ test_doclinkchecker() {
 }
 do_test doc doclinkchecker
 
-stop_api
+stop_services
 
 test_apiserver() {
     cd "$WORKSPACE/services/api" \
@@ -635,19 +651,22 @@ do
 done
 
 test_workbench() {
-    cd "$WORKSPACE/apps/workbench" \
+    start_nginx_proxy_services \
+        && cd "$WORKSPACE/apps/workbench" \
         && RAILS_ENV=test bundle exec rake test TESTOPTS=-v ${testargs[apps/workbench]}
 }
 do_test apps/workbench workbench
 
 test_workbench_benchmark() {
-    cd "$WORKSPACE/apps/workbench" \
+    start_nginx_proxy_services \
+        && cd "$WORKSPACE/apps/workbench" \
         && RAILS_ENV=test bundle exec rake test:benchmark ${testargs[apps/workbench_benchmark]}
 }
 do_test apps/workbench_benchmark workbench_benchmark
 
 test_workbench_profile() {
-    cd "$WORKSPACE/apps/workbench" \
+    start_nginx_proxy_services \
+        && cd "$WORKSPACE/apps/workbench" \
         && RAILS_ENV=test bundle exec rake test:profile ${testargs[apps/workbench_profile]}
 }
 do_test apps/workbench_profile workbench_profile

commit 9186a0819f789b3098ef3fcebaf92724069e874b
Author: Tom Clegg <tom at curoverse.com>
Date:   Thu Apr 2 20:15:58 2015 -0400

    5416: Terminate connections on the configured test database (not necessarily arvados_test).

diff --git a/jenkins/run-tests.sh b/jenkins/run-tests.sh
index c81f3bd..545c847 100755
--- a/jenkins/run-tests.sh
+++ b/jenkins/run-tests.sh
@@ -547,9 +547,11 @@ install_apiserver() {
         && git add tmp \
         && git commit -m 'initial commit'
 
-    # Clear out any lingering postgresql connections to arvados_test, so that we can drop it
-    # This assumes the current user is a postgresql superuser
-    psql arvados_test -c "SELECT pg_terminate_backend (pg_stat_activity.procpid::int) FROM pg_stat_activity WHERE pg_stat_activity.datname = 'arvados_test';" 2>/dev/null
+    # Clear out any lingering postgresql connections to the test
+    # database, so that we can drop it. This assumes the current user
+    # is a postgresql superuser.
+    test_database=$(python -c "import yaml; print yaml.load(file('config/database.yml'))['test']['database']")
+    psql "$test_database" -c "SELECT pg_terminate_backend (pg_stat_activity.procpid::int) FROM pg_stat_activity WHERE pg_stat_activity.datname = '$test_database';" 2>/dev/null
 
     cd "$WORKSPACE/services/api" \
         && RAILS_ENV=test bundle exec rake db:drop \

-----------------------------------------------------------------------


hooks/post-receive
-- 




More information about the arvados-commits mailing list